==> cloudt-platform-service-0.2.4.7.2-20240119.050427-6-sources.jar: com/elitescloud/cloudt/platform/service/repo/SysPlatformMenusRepoProc.java <==
package com.elitescloud.cloudt.platform.service.repo;

import com.elitescloud.boot.jpa.common.BaseRepoProc;
import com.elitescloud.cloudt.platform.model.entity.QSysPlatformMenusApiDO;
import com.elitescloud.cloudt.platform.model.entity.QSysPlatformMenusDO;
import com.elitescloud.cloudt.platform.model.entity.SysPlatformMenusDO;
import com.elitescloud.cloudt.platform.model.params.menus.QueryMenusParam;
import com.elitescloud.cloudt.platform.model.vo.SysPlatformMenusApiVO;
import com.querydsl.core.types.Expression;
import com.querydsl.core.types.Projections;
import com.querydsl.jpa.JPAExpressions;
import org.springframework.stereotype.Repository;

import javax.validation.constraints.NotBlank;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

/**
 * .
 *
 * @author Kaiser（wang shao）
 * 2022/10/17
 */
@Repository
public class SysPlatformMenusRepoProc extends BaseRepoProc<SysPlatformMenusDO> {
    private static final QSysPlatformMenusDO QDO = QSysPlatformMenusDO.sysPlatformMenusDO;
    private static final QSysPlatformMenusApiDO QAPI = QSysPlatformMenusApiDO.sysPlatformMenusApiDO;

    public SysPlatformMenusRepoProc() {
        super(QDO);
    }

    public String getAppCode(String menusCode) {
        return jpaQueryFactory.select(QDO.menusAppCode)
                .from(QDO)
                .where(QDO.menusCode.eq(menusCode))
                .limit(1)
                .fetchOne();
    }

    /****
     * 查询菜单和菜单的api个数。 采用嵌套查询 原来是循环效率低。
     * @param appCode
     * @return
     */
    public List<SysPlatformMenusApiVO> getMenusSumApi(String appCode) {
        Expression<Long> apiNumExpr = JPAExpressions.select(QAPI.id.count().as("apiNum"))
                .from(QAPI)
                .where(QAPI.menusId.eq(QDO.id));

        return jpaQueryFactory.select(
                        Projections.constructor(
                                SysPlatformMenusApiVO.class,
                                QDO,
                                apiNumExpr
                        )
                )
                .from(QDO)
                .where(QDO.menusAppCode.eq(appCode).and(QDO.deleteFlag.eq(0)))
                .fetch();
    }

    /**
     * 根据应用编码删除
     *
     * @param appCode 应用编码
     */
    public void deleteByApp(@NotBlank String appCode) {
        super.deleteByValue(QDO.menusAppCode, appCode);
    }

    /**
     * 获取菜单列表管理
     *
     * @param queryMenusParam 查询参数
     * @return 菜单列表
     */
    public List<SysPlatformMenusDO> queryListMng(QueryMenusParam queryMenusParam) {
        var predicate = PredicateBuilder.builder()
                .andEq(QDO.menusAppCode, queryMenusParam.getAppCode())
                .andLike(QDO.menusName, queryMenusParam.getMenusName())
                .andLike(QDO.menusCode, queryMenusParam.getMenusCode())
                .and(queryMenusParam.getMenusType() != null, () -> QDO.menusType.eq(queryMenusParam.getMenusType().name()))
                .andEq(QDO.menusState, queryMenusParam.getMenusState())
                .andEq(QDO.nodeType, queryMenusParam.getNodeType())
                .build();
        return super.getList(predicate)
                .stream()
                .sorted(Comparator.comparing(SysPlatformMenusDO::getMenusOrder, Comparator.nullsFirst(Integer::compareTo).reversed()))
                .collect(Collectors.toList());
    }

    /**
     * 根据菜单编码获取菜单信息
     *
     * @param menusCode 菜单编码
     * @return 菜单信息
     */
    public SysPlatformMenusDO getByMenusCode(@NotBlank String menusCode) {
        return super.getOneByValue(QDO.menusCode, menusCode);
    }
}

==> cloudt-platform-service-0.2.10-20240422.035743-1-sources.jar: com/elitescloud/cloudt/platform/service/repo/SysPlatformMenusRepoProc.java <==
package com.elitescloud.cloudt.platform.service.repo;

import com.elitescloud.boot.jpa.common.BaseRepoProc;
import com.elitescloud.cloudt.platform.model.entity.QSysMenuOperationDO;
import com.elitescloud.cloudt.platform.model.entity.QSysPlatformMenusApiDO;
import com.elitescloud.cloudt.platform.model.entity.QSysPlatformMenusDO;
import com.elitescloud.cloudt.platform.model.entity.SysPlatformMenusDO;
import com.elitescloud.cloudt.platform.model.params.menus.QueryMenusParam;
import com.elitescloud.cloudt.platform.model.vo.MenusAndOperationNumVO;
import com.elitescloud.cloudt.system.service.model.entity.QSysBusinessOperationDO;
import com.querydsl.core.types.Expression;
import com.querydsl.core.types.Projections;
import com.querydsl.jpa.JPAExpressions;
import org.springframework.stereotype.Repository;

import javax.validation.constraints.NotBlank;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

/**
 * .
 *
 * @author Kaiser（wang shao）
 * 2022/10/17
 */
@Repository
public class SysPlatformMenusRepoProc extends BaseRepoProc<SysPlatformMenusDO> {
    private static final QSysPlatformMenusDO QDO = QSysPlatformMenusDO.sysPlatformMenusDO;
    private static final QSysPlatformMenusApiDO QDO_API = QSysPlatformMenusApiDO.sysPlatformMenusApiDO;
    private static final QSysMenuOperationDO QDO_MENU_OPERATION = QSysMenuOperationDO.sysMenuOperationDO;
    private static final QSysBusinessOperationDO QDO_OPERATION = QSysBusinessOperationDO.sysBusinessOperationDO;

    public SysPlatformMenusRepoProc() {
        super(QDO);
    }

    public String getAppCode(String menusCode) {
        return jpaQueryFactory.select(QDO.menusAppCode)
                .from(QDO)
                .where(QDO.menusCode.eq(menusCode))
                .limit(1)
                .fetchOne();
    }

    /****
     * 查询菜单和菜单的api个数。 采用嵌套查询 原来是循环效率低。
     * @param appCode
     * @return
     */
    public List<MenusAndOperationNumVO> getMenusSumApi(String appCode) {
        Expression<Long> apiNumExpr = JPAExpressions.select(QDO_API.id.count().as("apiNum"))
                .from(QDO_API)
                .where(QDO_API.menusId.eq(QDO.id));

        return jpaQueryFactory.select(
                        Projections.constructor(
                                MenusAndOperationNumVO.class,
                                QDO,
                                apiNumExpr
                        )
                )
                .from(QDO)
                .where(QDO.menusAppCode.eq(appCode).and(QDO.deleteFlag.eq(0)))
                .fetch();
    }

    /**
     * 获取菜单信息及其关联的api数量
     * <p>
     * 查询菜单和菜单的api个数。 采用嵌套查询 原来是循环效率低
     *
     * @param appCode
     * @return
     */
    public List<MenusAndOperationNumVO> getMenusAndCountOperation(String appCode) {
        Expression<Long> apiNumExpr = JPAExpressions.select(QDO_MENU_OPERATION.id.count().as("apiNum"))
                .from(QDO_MENU_OPERATION)
                .where(QDO_MENU_OPERATION.menusCode.eq(QDO.menusCode).and(
                        JPAExpressions.select(QDO_OPERATION.id).from(QDO_OPERATION).where(QDO_OPERATION.operationCode.eq(QDO_MENU_OPERATION.operationCode)).exists()
                ));

        return jpaQueryFactory.select(
                        Projections.constructor(
                                MenusAndOperationNumVO.class,
                                QDO,
                                apiNumExpr
                        )
                )
                .from(QDO)
                .where(QDO.menusAppCode.eq(appCode).and(QDO.deleteFlag.eq(0)))
                .fetch();
    }

    /**
     * 根据应用编码删除
     *
     * @param appCode 应用编码
     */
    public void deleteByApp(@NotBlank String appCode) {
        super.deleteByValue(QDO.menusAppCode, appCode);
    }

    /**
     * 获取菜单列表管理
     *
     * @param queryMenusParam 查询参数
     * @return 菜单列表
     */
    public List<SysPlatformMenusDO> queryListMng(QueryMenusParam queryMenusParam) {
        var predicate = PredicateBuilder.builder()
                .andEq(QDO.menusAppCode, queryMenusParam.getAppCode())
                .andLike(QDO.menusName, queryMenusParam.getMenusName())
                .andLike(QDO.menusCode, queryMenusParam.getMenusCode())
                .and(queryMenusParam.getMenusType() != null, () -> QDO.menusType.eq(queryMenusParam.getMenusType().name()))
                .andEq(QDO.menusState, queryMenusParam.getMenusState())
                .andEq(QDO.nodeType, queryMenusParam.getNodeType())
                .build();
        return super.getList(predicate)
                .stream()
                .sorted(Comparator.comparing(SysPlatformMenusDO::getMenusOrder, Comparator.nullsFirst(Integer::compareTo).reversed()))
                .collect(Collectors.toList());
    }

    /**
     * 根据菜单编码获取菜单信息
     *
     * @param menusCode 菜单编码
     * @return 菜单信息
     */
    public SysPlatformMenusDO getByMenusCode(@NotBlank String menusCode) {
        return super.getOneByValue(QDO.menusCode, menusCode);
    }
}
